@@ -32,6 +32,7 @@ struct load {
 	unsigned long system;
 	unsigned long nice;
 	unsigned long idle;
+	char *cpu;
 };
 
 struct meminfo {
@@ -46,5 +47,6 @@ extern void get_meminfo( int *, struct meminfo * );
 extern double get_loadavg(void);
 extern void get_load(struct load *);
 extern int sysinfo_init(void);
+extern int get_total_procs( void );
 
 #endif
